==> storage_capacity-0.0.5.tar.gz: android/src/main/kotlin/io/komus/storage_capacity/StorageCapacityPlugin.kt <==
package io.komus.storage_capacity

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import  android.os.StatFs
import  android.os.Environment

/** StorageCapacityPlugin */
public class StorageCapacityPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "storage_capacity")
    channel.setMethodCallHandler(this);
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "storage_capacity")
      channel.setMethodCallHandler(StorageCapacityPlugin())
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }
    else if(call.method == "getFreeSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())
      val bytesAvailable = stat.getFreeBytes()
      result.success(bytesAvailable)
    }
    else if(call.method == "getOccupiedSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())
      val bytesOccupied = stat.getTotalBytes()
      result.success(bytesOccupied)
    } else if(call.method == "getTotalSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())
      val bytesAvailable = stat.getFreeBytes()
      val bytesOccupied = stat.getTotalBytes()
      result.success(bytesOccupied+bytesAvailable)
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> storage_capacity-0.0.7.tar.gz: android/src/main/kotlin/io/komus/storage_capacity/StorageCapacityPlugin.kt <==
package io.komus.storage_capacity

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import  android.os.StatFs
import  android.os.Environment

/** StorageCapacityPlugin */
public class StorageCapacityPlugin: FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "storage_capacity")
    channel.setMethodCallHandler(this);
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "storage_capacity")
      channel.setMethodCallHandler(StorageCapacityPlugin())
    }
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }
    else if(call.method == "getFreeSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())
      val bytesAvailable = stat.getAvailableBytes()
      result.success(bytesAvailable)
    }
    else if(call.method == "getOccupiedSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())
      val bytesAvailable = stat.getAvailableBytes()
      val bytesOccupied = stat.getTotalBytes()
      result.success(bytesOccupied - bytesAvailable)
    } else if(call.method == "getTotalSpace"){
      val stat = StatFs(Environment.getDataDirectory().getPath())

      result.success(stat.getTotalBytes())
    }
    else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
